@@ -153,7 +153,7 @@ setMethod("Math", "glub",
                    asinh  = {     log(   x +    sqrt( 1+x*x)) },
                    atan   = { 0.5i*log((1i+x)/(1i-x)) },
                    atanh  = { 0.5 *log((1 +x)/(1 -x)) },
-                   trunc  = callGeneric(as.complex(x)),,,
+                   trunc  = callGeneric(as.complex(x)),
                    lgamma =,
                    cumsum =,
                    gamma  =,
