@@ -1,5 +1,13 @@
+### R code from vignette source 'brob.Rnw'
+
 ###################################################
-### chunk number 2: 
+### code chunk number 1: setClass
+###################################################
+
+
+
+###################################################
+### code chunk number 2: brob.Rnw:120-129
 ###################################################
 setClass("swift",
          representation = "VIRTUAL"
@@ -13,19 +21,19 @@ setClass("brob",
 
 
 ###################################################
-### chunk number 3: new
+### code chunk number 3: new
 ###################################################
 new("brob",x=1:10,positive=rep(TRUE,10))
 
 
 ###################################################
-### chunk number 4: new_flaky_arguments
+### code chunk number 4: new_flaky_arguments
 ###################################################
 new("brob",x=1:10,positive=c(TRUE,FALSE,FALSE))
 
 
 ###################################################
-### chunk number 5: validity_method
+### code chunk number 5: validity_method
 ###################################################
 .Brob.valid <- function(object){
   len <- length(object@positive)
@@ -38,13 +46,13 @@ new("brob",x=1:10,positive=c(TRUE,FALSE,FALSE))
 
 
 ###################################################
-### chunk number 6: call_setValidity
+### code chunk number 6: call_setValidity
 ###################################################
 setValidity("brob", .Brob.valid)
 
 
 ###################################################
-### chunk number 7: brob_definition
+### code chunk number 7: brob_definition
 ###################################################
 "brob" <- function(x=double(),positive){
   if(missing(positive)){
@@ -58,26 +66,26 @@ setValidity("brob", .Brob.valid)
 
 
 ###################################################
-### chunk number 8: call_brob_recycling
+### code chunk number 8: call_brob_recycling
 ###################################################
 brob(1:10,FALSE)
 
 
 ###################################################
-### chunk number 9: use.function.is
+### code chunk number 9: use.function.is
 ###################################################
 is(brob(1:5),"brob")
 
 
 ###################################################
-### chunk number 10: is.brob_definition
+### code chunk number 10: is.brob_definition
 ###################################################
 is.brob <- function(x){is(x,"brob")}
 is.glub <- function(x){is(x,"glub")}
 
 
 ###################################################
-### chunk number 11: as.brob_definition
+### code chunk number 11: as.brob_definition
 ###################################################
 "as.brob" <- function(x){
   if(is.brob(x)){
@@ -95,13 +103,19 @@ is.glub <- function(x){is(x,"glub")}
 
 
 ###################################################
-### chunk number 12: as.brob_call
+### code chunk number 12: as.brob_call
 ###################################################
 as.brob(1:10)
 
 
 ###################################################
-### chunk number 14: 
+### code chunk number 13: setAs
+###################################################
+
+
+
+###################################################
+### code chunk number 14: brob.Rnw:366-371
 ###################################################
 setAs("brob", "numeric", function(from){
   out <- exp(from@x)
@@ -111,13 +125,13 @@ setAs("brob", "numeric", function(from){
 
 
 ###################################################
-### chunk number 15: setMethodbrob
+### code chunk number 15: setMethodbrob
 ###################################################
 setMethod("as.numeric",signature(x="brob"),function(x){as(x,"numeric")})
 
 
 ###################################################
-### chunk number 16: setAsbrobcomplex
+### code chunk number 16: setAsbrobcomplex
 ###################################################
 setAs("brob", "complex", function(from){
   return(as.numeric(from)+ 0i)
@@ -127,7 +141,7 @@ setMethod("as.complex",signature(x="brob"),function(x){as(x,"complex")})
 
 
 ###################################################
-### chunk number 17: asCheck
+### code chunk number 17: asCheck
 ###################################################
 x <- as.brob(1:4)
 x
@@ -135,7 +149,7 @@ as.numeric(x)
 
 
 ###################################################
-### chunk number 18: print_methods
+### code chunk number 18: print_methods
 ###################################################
 .Brob.print <- function(x, digits=5){
      noquote( paste(c("-","+")[1+x@positive],"exp(",signif(x@x,digits),")",sep=""))
@@ -143,7 +157,7 @@ as.numeric(x)
 
 
 ###################################################
-### chunk number 19: print.brob
+### code chunk number 19: print.brob
 ###################################################
 print.brob <- function(x, ...){
   jj <- .Brob.print(x, ...)
@@ -153,19 +167,25 @@ print.brob <- function(x, ...){
 
 
 ###################################################
-### chunk number 20: setmethodbrobshow
+### code chunk number 20: setmethodbrobshow
 ###################################################
 setMethod("show", "brob", function(object){print.brob(object)})
 
 
 ###################################################
-### chunk number 21: as.brob14
+### code chunk number 21: as.brob14
 ###################################################
 as.brob(1:4)
 
 
 ###################################################
-### chunk number 23: 
+### code chunk number 22: get.n.set
+###################################################
+
+
+
+###################################################
+### code chunk number 23: brob.Rnw:465-469
 ###################################################
 setGeneric("getX",function(x){standardGeneric("getX")})
 setGeneric("getP",function(x){standardGeneric("getP")})
@@ -174,13 +194,25 @@ setMethod("getP","brob",function(x){x@positive})
 
 
 ###################################################
-### chunk number 25: 
+### code chunk number 24: setlength
+###################################################
+
+
+
+###################################################
+### code chunk number 25: brob.Rnw:481-482
 ###################################################
 setMethod("length","brob",function(x){length(x@x)})
 
 
 ###################################################
-### chunk number 27: 
+### code chunk number 26: setmethodSquareBrace
+###################################################
+
+
+
+###################################################
+### code chunk number 27: brob.Rnw:492-499
 ###################################################
 setMethod("[", "brob",
           function(x, i, j,  drop){
@@ -192,7 +224,13 @@ setMethod("[", "brob",
 
 
 ###################################################
-### chunk number 29: 
+### code chunk number 28: setReplaceMethod
+###################################################
+
+
+
+###################################################
+### code chunk number 29: brob.Rnw:512-529
 ###################################################
 setReplaceMethod("[",signature(x="brob"),
                  function(x,i,j,value){
@@ -214,7 +252,7 @@ setReplaceMethod("[",signature(x="brob"),
 
 
 ###################################################
-### chunk number 30: .Brob.cPair
+### code chunk number 30: .Brob.cPair
 ###################################################
 .Brob.cPair <- function(x,y){
   x <- as.brob(x)
@@ -224,13 +262,25 @@ setReplaceMethod("[",signature(x="brob"),
 
 
 ###################################################
-### chunk number 32: 
+### code chunk number 31: setGeneric_cbrob
+###################################################
+
+
+
+###################################################
+### code chunk number 32: brob.Rnw:568-569
 ###################################################
 setGeneric(".cPair", function(x,y){standardGeneric(".cPair")})
 
 
 ###################################################
-### chunk number 34: 
+### code chunk number 33: setMethod.Cpair
+###################################################
+
+
+
+###################################################
+### code chunk number 34: brob.Rnw:579-583
 ###################################################
 setMethod(".cPair", c("brob", "brob"), function(x,y){.Brob.cPair(x,y)})
 setMethod(".cPair", c("brob", "ANY"),  function(x,y){.Brob.cPair(x,as.brob(y))})
@@ -239,7 +289,7 @@ setMethod(".cPair", c("ANY", "ANY"),   function(x,y){c(x,y)})
 
 
 ###################################################
-### chunk number 35: cbrob
+### code chunk number 35: cbrob
 ###################################################
 "cbrob" <- function(x, ...) {
    if(nargs()<3)
@@ -250,7 +300,7 @@ setMethod(".cPair", c("ANY", "ANY"),   function(x,y){c(x,y)})
 
 
 ###################################################
-### chunk number 36: test.cbrob
+### code chunk number 36: test.cbrob
 ###################################################
 a <- 1:3
 b <- as.brob(1e100)
@@ -258,7 +308,13 @@ cbrob(a,a,b,a)
 
 
 ###################################################
-### chunk number 38: 
+### code chunk number 37: sqrtmethod
+###################################################
+
+
+
+###################################################
+### code chunk number 38: brob.Rnw:633-636
 ###################################################
 setMethod("sqrt","brob", function(x){
  brob(ifelse(x@positive,x@x/2, NaN),TRUE)
@@ -266,13 +322,19 @@ setMethod("sqrt","brob", function(x){
 
 
 ###################################################
-### chunk number 39: checklogsqrt
+### code chunk number 39: checklogsqrt
 ###################################################
 sqrt(brob(4))
 
 
 ###################################################
-### chunk number 41: 
+### code chunk number 40: mathgeneric
+###################################################
+
+
+
+###################################################
+### code chunk number 41: brob.Rnw:648-679
 ###################################################
 setMethod("Math", "brob",
           function(x){
@@ -308,13 +370,13 @@ setMethod("Math", "brob",
 
 
 ###################################################
-### chunk number 42: checktrig
+### code chunk number 42: checktrig
 ###################################################
 sin(brob(4))
 
 
 ###################################################
-### chunk number 43: .brob.arithstuff
+### code chunk number 43: .brob.arithstuff
 ###################################################
 .Brob.negative <- function(e1){
   brob(e1@x,!e1@positive)
@@ -370,7 +432,13 @@ sin(brob(4))
 
 
 ###################################################
-### chunk number 45: 
+### code chunk number 44: setMethodArithUnary
+###################################################
+
+
+
+###################################################
+### code chunk number 45: brob.Rnw:771-780
 ###################################################
 setMethod("Arith",signature(e1 = "brob", e2="missing"),
           function(e1,e2){
@@ -384,13 +452,13 @@ setMethod("Arith",signature(e1 = "brob", e2="missing"),
 
 
 ###################################################
-### chunk number 46: check_minus_5
+### code chunk number 46: check_minus_5
 ###################################################
 -brob(5)
 
 
 ###################################################
-### chunk number 47: brob.arith
+### code chunk number 47: brob.arith
 ###################################################
 .Brob.arith <- function(e1,e2){
   switch(.Generic,
@@ -404,7 +472,7 @@ setMethod("Arith",signature(e1 = "brob", e2="missing"),
 
 
 ###################################################
-### chunk number 48: setMethodArith
+### code chunk number 48: setMethodArith
 ###################################################
 setMethod("Arith", signature(e1 = "brob", e2="ANY"), .Brob.arith)
 setMethod("Arith", signature(e1 = "ANY", e2="brob"), .Brob.arith)
@@ -412,13 +480,13 @@ setMethod("Arith", signature(e1 = "brob", e2="brob"), .Brob.arith)
 
 
 ###################################################
-### chunk number 49: check_addition
+### code chunk number 49: check_addition
 ###################################################
 1e100 + as.brob(10)^100
 
 
 ###################################################
-### chunk number 50: brob.equalandgreater
+### code chunk number 50: brob.equalandgreater
 ###################################################
 .Brob.equal <- function(e1,e2){
   (e1@x==e2@x) & (e1@positive==e2@positive)
@@ -439,7 +507,7 @@ setMethod("Arith", signature(e1 = "brob", e2="brob"), .Brob.arith)
 
 
 ###################################################
-### chunk number 51: brob.compare
+### code chunk number 51: brob.compare
 ###################################################
 ".Brob.compare" <- function(e1,e2){
   e1 <- as.brob(e1)
@@ -457,7 +525,13 @@ setMethod("Arith", signature(e1 = "brob", e2="brob"), .Brob.arith)
 
 
 ###################################################
-### chunk number 53: 
+### code chunk number 52: setMethodCompare
+###################################################
+
+
+
+###################################################
+### code chunk number 53: brob.Rnw:876-879
 ###################################################
 setMethod("Compare", signature(e1="brob", e2="ANY" ), .Brob.compare)
 setMethod("Compare", signature(e1="ANY" , e2="brob"), .Brob.compare)
@@ -465,14 +539,14 @@ setMethod("Compare", signature(e1="brob", e2="brob"), .Brob.compare)
 
 
 ###################################################
-### chunk number 54: check.compare
+### code chunk number 54: check.compare
 ###################################################
 as.brob(10) < as.brob(11)
 as.brob(10) <= as.brob(10)
 
 
 ###################################################
-### chunk number 55: brob.logic
+### code chunk number 55: brob.logic
 ###################################################
 .Brob.logic <- function(e1,e2){
   stop("No logic currently implemented for Brobdingnagian numbers")
@@ -480,7 +554,13 @@ as.brob(10) <= as.brob(10)
 
 
 ###################################################
-### chunk number 57: 
+### code chunk number 56: setmethodlogic
+###################################################
+
+
+
+###################################################
+### code chunk number 57: brob.Rnw:910-913
 ###################################################
 setMethod("Logic",signature(e1="swift",e2="ANY"), .Brob.logic)
 setMethod("Logic",signature(e1="ANY",e2="swift"), .Brob.logic)
@@ -488,7 +568,7 @@ setMethod("Logic",signature(e1="swift",e2="swift"), .Brob.logic)
 
 
 ###################################################
-### chunk number 58: logchunk
+### code chunk number 58: logchunk
 ###################################################
 if(!isGeneric("log")){
   setGeneric("log",group="Math")
@@ -496,10 +576,15 @@ if(!isGeneric("log")){
 
 
 ###################################################
-### chunk number 60: 
+### code chunk number 59: miscgenerics
 ###################################################
-if(!isGeneric("log")){
-print("asdfAF")
+
+
+
+###################################################
+### code chunk number 60: brob.Rnw:958-1009
+###################################################
+if(!isGeneric("sum")){
 setGeneric("max", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("max")
@@ -553,7 +638,7 @@ setGeneric("sum", function(x, ..., na.rm = FALSE)
 
 
 ###################################################
-### chunk number 61: brob.maxmin
+### code chunk number 61: brob.maxmin
 ###################################################
 .Brob.max <- function(x, ..., na.rm=FALSE){
   p <- x@positive
@@ -587,11 +672,16 @@ setGeneric("sum", function(x, ..., na.rm = FALSE)
 
 
 ###################################################
-### chunk number 63: 
+### code chunk number 62: setmethodsummary
+###################################################
+
+
+
+###################################################
+### code chunk number 63: brob.Rnw:1055-1067
 ###################################################
 setMethod("Summary", "brob",
           function(x, ..., na.rm=FALSE){
-            browser()
             switch(.Generic,
                    max    =  .Brob.max( x, ..., na.rm=na.rm),
                    min    = -.Brob.max(-x, ..., na.rm=na.rm),
@@ -605,26 +695,32 @@ setMethod("Summary", "brob",
 
 
 ###################################################
-### chunk number 64: factorial
+### code chunk number 64: checksum
+###################################################
+sum(as.brob(1:100)) - 5050
+
+
+###################################################
+### code chunk number 65: factorial
 ###################################################
 stirling <- function(x){sqrt(2*pi*x)*exp(-x)*x^x}
 
 
 ###################################################
-### chunk number 65: use.stirling
+### code chunk number 66: use.stirling
 ###################################################
 stirling(100)
 stirling(as.brob(100))
 
 
 ###################################################
-### chunk number 66: compare.two.stirlings
+### code chunk number 67: compare.two.stirlings
 ###################################################
 as.numeric(stirling(100)/stirling(as.brob(100)))
 
 
 ###################################################
-### chunk number 67: stirling.of.1000
+### code chunk number 68: stirling.of.1000
 ###################################################
 stirling(1000)
 stirling(as.brob(1000))
